pub struct DtcStatus {
pub test_failed: bool,
pub test_failed_this_operation_cycle: bool,
pub pending: bool,
pub confirmed: bool,
pub test_not_completed_since_clear: bool,
pub test_failed_since_clear: bool,
pub test_not_completed_this_operation_cycle: bool,
pub warning_indicator: bool,
}Expand description
Standard UDS diagnostic status bits for a trouble code.
Fields
test_failed: boolThe DTC test is failed now.
test_failed_this_operation_cycle: boolThe DTC test failed during the current operation cycle.
pending: boolThe DTC is pending confirmation.
confirmed: boolThe DTC is confirmed.
test_not_completed_since_clear: boolThe DTC has not completed since the last clear operation.
test_failed_since_clear: boolThe DTC failed at least once since the last clear operation.
test_not_completed_this_operation_cycle: boolThe DTC test has not completed in the current operation cycle.
warning_indicator: boolThe warning indicator is requested.
Implementations