Module select

Module select 

Brand and site selection over open automotive manifest data.

Structs

BrandNeed
A requested vehicle make, lanes, and optional capability ceiling.
BrandSelection
The selected manifest and derived brand capabilities.

Functions

installed_brand_caps
Derives brand capability rows for all installed manifests.
select_brand
Returns the best manifest for need.
select_brand_caps
Returns the best manifest’s brand capabilities for need.