BrandNeed

Struct BrandNeed 

pub struct BrandNeed {
    pub make: String,
    pub lanes: Vec<AutoLane>,
    pub capabilities: Vec<CapabilityName>,
}
A requested vehicle make, lanes, and optional capability ceiling.

Fields

make: String

Requested vehicle make, such as volvo or mercedes-benz.

lanes: Vec<AutoLane>

Lanes required for the current bay action.

capabilities: Vec<CapabilityName>

Capabilities the selected site must be allowed to hold.

Implementations

Source

impl BrandNeed

pub fn new(make: impl Into<String>, lanes: Vec<AutoLane>) -> Self

Builds a brand-selection request.

pub fn requiring(self, capability: CapabilityName) -> Self

Adds one required capability to the selection request.